# Copyright 2019 Extreme Networks, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

TASK_STATE_ROUTE_FORMAT = "%s__r%s"
TASK_STATE_TRANSITION_FORMAT = "%s__t%s"

INBOUND_CRITERIA_WIP = "inbound_criteria_wip"
INBOUND_CRITERIA_SATISFIED = "inbound_criteria_satisfied"
INBOUND_CRITERIA_NOT_SATISFIED = "inbound_criteria_not_satisfied"
